2.0.2 (2018-09-25)
------------------

- Remove login endpoint because guillotina already offers it
  [bloodbare]


2.0.1 (2018-07-19)
------------------

- Support both `username` and `login` as parameter for the `@login` endpoint
  [ebrehault]


2.0.0 (2018-07-19)
------------------

- Work with guillotina 4
  [vangheem]


1.0.1 (2017-10-08)
------------------

- Fix issues with user definition on latest guillotina
  [vangheem]

- Automatically configure
  [vangheem]


1.0.0 (2017-04-11)
------------------

- initial move to guillotina
  [vangheem]
